@@ -54,7 +54,7 @@ class CrudSchema(BaseSchema):
             self.FIELDS += list(self.SUB_CLASSES.keys())
             self.fields_data = [f for f in self.model_class._meta.fields if f.name in self.FIELDS]
         else:
-                self.fields_data = self.model_class._meta.fields
+            self.fields_data = self.model_class._meta.fields
         self.annotations = self.ANNOTATIONS
         self.required_fields = [f.name for f in self.fields_data if not f.blank]
 
@@ -146,9 +146,13 @@ class CrudSchema(BaseSchema):
                     many_models_data[item.id].append((field, data.pop(field)))
                 else:
                     many_models_data.pop(item.id)
-
+            print('in put ')
             for key, value in data.items():
+                print(key, value)
                 setattr(item, key, value)
+
+            print(data)
+            print(item.editor)
             item.full_clean()
             res.append(item)
 
@@ -161,14 +165,20 @@ class CrudSchema(BaseSchema):
                     exec(f'item.{field}.clear()')
                     exec(f'item.{field}.add({ids})')
 
+        if not item_ids:
+            raise Error(field_name='id', message='Item(s) not found.', status=HttpStatus.HTTP_404_NOT_FOUND)
         self.filters = {'id__in': item_ids}
         return self.get()
 
     def delete(self, **data):
         if not self.DELETE:
             raise Error(field_name=None, message='DELETE not allowed', status=HttpStatus.HTTP_405_METHOD_NOT_ALLOWED)
+
+        items = self.get_queryset()
+        if not items.exists():
+            raise Error(field_name='id', message='Item(s) not found.', status=HttpStatus.HTTP_404_NOT_FOUND)
         if data:  # Update date like editor before delete
-            for item in self.get_queryset():
+            for item in items:
                 for k, v in data.items():
                     setattr(item, k, v)
                 item.save()
@@ -376,4 +386,4 @@ paths:
             f.write(self.swagger_doc())
 
         with open(self.docs_path_to_html, 'w') as f:
-            f.write(self._get_html_template())
\ No newline at end of file
+            f.write(self._get_html_template())
